==> hexalate_1.0.2.orig.tar.bz2: hexalate-1.0.2/translations/hexalate_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Abort current game?</source>
        <translation>¿Abortar la partida actual?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor, reinicie la aplicación para el cambio de idioma tenga efecto.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <location filename="../src/puzzle.cpp" line="162"/>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>No se ha podido cargar la última partida. Empezando una nueva.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="34"/>
        <location filename="../src/window.cpp" line="75"/>
        <source>Hexalate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="42"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="42"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="46"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuraciones</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="47"/>
        <source>Application &amp;Language...</source>
        <translation>Idioma de la &amp;Aplicación...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="50"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="51"/>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>About Hexalate</source>
        <translation>Acerca de Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>A color matching game</source>
        <translation>Un juego de combinación de colores</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="77"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="78"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> hexalate_1.0.3.orig.tar.bz2: hexalate-1.0.3/translations/hexalate_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Abort current game?</source>
        <translation>¿Quiere interrumpir la partida actual?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie la aplicación para el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <location filename="../src/puzzle.cpp" line="162"/>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Sorry</source>
        <translation>Lo sentimos</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>No se ha podido cargar la última partida. Empezando una nueva.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="33"/>
        <location filename="../src/window.cpp" line="74"/>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="40"/>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>&amp;New</source>
        <translation>&amp;Nueva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="43"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="43"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="45"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="46"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación…</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="48"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="50"/>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="73"/>
        <source>About Hexalate</source>
        <translation>Acerca de Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="75"/>
        <source>A color matching game</source>
        <translation>Un juego de igualación de colores</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="77"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
